@@ -8,6 +8,7 @@ from django.db.models import Case, Value, When
 from django.forms.widgets import Select
 from django.template.defaultfilters import pluralize
 from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 from kombu.utils.json import loads
 
 from .models import (ClockedSchedule, CrontabSchedule, IntervalSchedule,
@@ -23,8 +24,8 @@ class TaskSelectWidget(Select):
 
     def tasks_as_choices(self):
         _ = self._modules
-        tasks = list(sorted(name for name in self.celery_app.tasks
-                            if not name.startswith('celery.')))
+        tasks = sorted(name for name in self.celery_app.tasks
+                       if not name.startswith('celery.'))
         return (('', ''), ) + tuple(zip(tasks, tasks))
 
     @property
@@ -105,6 +106,7 @@ class PeriodicTaskForm(forms.ModelForm):
         return self._clean_json('kwargs')
 
 
+@admin.register(PeriodicTask)
 class PeriodicTaskAdmin(admin.ModelAdmin):
     """Admin-interface for periodic tasks."""
 
@@ -112,7 +114,7 @@ class PeriodicTaskAdmin(admin.ModelAdmin):
     model = PeriodicTask
     celery_app = current_app
     date_hierarchy = 'start_time'
-    list_display = ('__str__', 'enabled', 'interval', 'start_time',
+    list_display = ('name', 'enabled', 'scheduler', 'interval', 'start_time',
                     'last_run_at', 'one_off')
     list_filter = ['enabled', 'one_off', 'task', 'start_time', 'last_run_at']
     actions = ('enable_tasks', 'disable_tasks', 'toggle_tasks', 'run_tasks')
@@ -123,8 +125,8 @@ class PeriodicTaskAdmin(admin.ModelAdmin):
             'classes': ('extrapretty', 'wide'),
         }),
         (_('Schedule'), {
-            'fields': ('interval', 'crontab', 'solar', 'clocked',
-                       'start_time', 'last_run_at', 'one_off'),
+            'fields': ('interval', 'crontab', 'crontab_translation', 'solar',
+                       'clocked', 'start_time', 'last_run_at', 'one_off'),
             'classes': ('extrapretty', 'wide'),
         }),
         (_('Arguments'), {
@@ -138,12 +140,28 @@ class PeriodicTaskAdmin(admin.ModelAdmin):
         }),
     )
     readonly_fields = (
-        'last_run_at',
+        'last_run_at', 'crontab_translation',
     )
 
+    def crontab_translation(self, obj):
+        return obj.crontab.human_readable
+
+    change_form_template = 'admin/djcelery/change_periodictask_form.html'
+
+    def changeform_view(self, request, object_id=None, form_url='',
+                        extra_context=None):
+        extra_context = extra_context or {}
+        crontabs = CrontabSchedule.objects.all()
+        crontab_dict = {}
+        for crontab in crontabs:
+            crontab_dict[crontab.id] = crontab.human_readable
+        extra_context['readable_crontabs'] = crontab_dict
+        return super().changeform_view(request, object_id,
+                                       extra_context=extra_context)
+
     def changelist_view(self, request, extra_context=None):
         extra_context = extra_context or {}
-        scheduler = getattr(settings, 'CELERYBEAT_SCHEDULER', None)
+        scheduler = getattr(settings, 'CELERY_BEAT_SCHEDULER', None)
         extra_context['wrong_scheduler'] = not is_database_scheduler(scheduler)
         return super().changelist_view(
             request, extra_context)
@@ -152,33 +170,35 @@ class PeriodicTaskAdmin(admin.ModelAdmin):
         qs = super().get_queryset(request)
         return qs.select_related('interval', 'crontab', 'solar', 'clocked')
 
-    def _message_user_about_update(self, request, rows_updated, verb):
-        """Send message about action to user.
-
-        `verb` should shortly describe what have changed (e.g. 'enabled').
-
-        """
-        self.message_user(
-            request,
-            _('{0} task{1} {2} successfully {3}').format(
-                rows_updated,
-                pluralize(rows_updated),
-                pluralize(rows_updated, _('was,were')),
-                verb,
-            ),
-        )
-
+    @admin.action(
+        description=_('Enable selected tasks')
+    )
     def enable_tasks(self, request, queryset):
         rows_updated = queryset.update(enabled=True)
         PeriodicTasks.update_changed()
-        self._message_user_about_update(request, rows_updated, 'enabled')
-    enable_tasks.short_description = _('Enable selected tasks')
+        self.message_user(
+            request,
+            ngettext_lazy(
+                '{0} task was successfully enabled',
+                '{0} tasks were successfully enabled',
+                rows_updated
+            ).format(rows_updated)
+        )
 
+    @admin.action(
+        description=_('Disable selected tasks')
+    )
     def disable_tasks(self, request, queryset):
         rows_updated = queryset.update(enabled=False, last_run_at=None)
         PeriodicTasks.update_changed()
-        self._message_user_about_update(request, rows_updated, 'disabled')
-    disable_tasks.short_description = _('Disable selected tasks')
+        self.message_user(
+            request,
+            ngettext_lazy(
+                '{0} task was successfully disabled',
+                '{0} tasks were successfully disabled',
+                rows_updated
+            ).format(rows_updated)
+        )
 
     def _toggle_tasks_activity(self, queryset):
         return queryset.update(enabled=Case(
@@ -186,12 +206,24 @@ class PeriodicTaskAdmin(admin.ModelAdmin):
             default=Value(True),
         ))
 
+    @admin.action(
+        description=_('Toggle activity of selected tasks')
+    )
     def toggle_tasks(self, request, queryset):
         rows_updated = self._toggle_tasks_activity(queryset)
         PeriodicTasks.update_changed()
-        self._message_user_about_update(request, rows_updated, 'toggled')
-    toggle_tasks.short_description = _('Toggle activity of selected tasks')
+        self.message_user(
+            request,
+            ngettext_lazy(
+                '{0} task was successfully toggled',
+                '{0} tasks were successfully toggled',
+                rows_updated
+            ).format(rows_updated)
+        )
 
+    @admin.action(
+        description=_('Run selected tasks')
+    )
     def run_tasks(self, request, queryset):
         self.celery_app.loader.import_default_modules()
         tasks = [(self.celery_app.tasks.get(task.task),
@@ -233,10 +265,28 @@ class PeriodicTaskAdmin(admin.ModelAdmin):
                 pluralize(tasks_run, _('was,were')),
             ),
         )
-    run_tasks.short_description = _('Run selected tasks')
 
 
-class ClockedScheduleAdmin(admin.ModelAdmin):
+class PeriodicTaskInline(admin.TabularInline):
+    model = PeriodicTask
+    fields = ('name', 'task', 'args', 'kwargs')
+    readonly_fields = fields
+    can_delete = False
+    extra = 0
+    show_change_link = True
+    verbose_name = "Periodic Tasks Using This Schedule"
+    verbose_name_plural = verbose_name
+
+    def has_add_permission(self, request, obj):
+        return False
+
+
+class ScheduleAdmin(admin.ModelAdmin):
+    inlines = [PeriodicTaskInline]
+
+
+@admin.register(ClockedSchedule)
+class ClockedScheduleAdmin(ScheduleAdmin):
     """Admin-interface for clocked schedules."""
 
     fields = (
@@ -247,8 +297,23 @@ class ClockedScheduleAdmin(admin.ModelAdmin):
     )
 
 
-admin.site.register(IntervalSchedule)
-admin.site.register(CrontabSchedule)
-admin.site.register(SolarSchedule)
-admin.site.register(ClockedSchedule, ClockedScheduleAdmin)
-admin.site.register(PeriodicTask, PeriodicTaskAdmin)
+@admin.register(CrontabSchedule)
+class CrontabScheduleAdmin(ScheduleAdmin):
+    """Admin class for CrontabSchedule."""
+
+    list_display = ('__str__', 'human_readable')
+    fields = ('human_readable', 'minute', 'hour', 'day_of_month',
+              'month_of_year', 'day_of_week', 'timezone')
+    readonly_fields = ('human_readable', )
+
+
+@admin.register(SolarSchedule)
+class SolarScheduleAdmin(ScheduleAdmin):
+    """Admin class for SolarSchedule."""
+    pass
+
+
+@admin.register(IntervalSchedule)
+class IntervalScheduleAdmin(ScheduleAdmin):
+    """Admin class for IntervalSchedule."""
+    pass
